@@ -21,9 +21,10 @@ def mk_readme(role: str):
   template.stream(template_vars).dump(role + '/README-butler.md')
 
 def get_yaml_dict(yml, key=None) -> dict:
-  parsed = {}
   if os.path.isfile(yml):
     parsed = parse_yml(yml)
+  else:
+    return {}
 
   if key:
     return { key: parsed }
